#
# spec file for package DSView
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           DSView
Version:        1.2.2
Release:        1.4
Summary:        GUI for DreamSourceLab USB-based instruments
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://www.dreamsourcelab.com
Source0:        https://github.com/DreamSourceLab/DSView/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(python3)
Obsoletes:      libsigrok4DSL1
Obsoletes:      libsigrokdecode4DSL4

%description
GUI for DreamSourceLab USB-based instruments

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}/libsigrokdecode4DSL/

%files
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/dsview.desktop
%{_datadir}/icons/hicolor/scalable/apps/dsview.svg
%{_datadir}/pixmaps/dsview.svg
%{_udevrulesdir}/*
%{_datadir}/libsigrokdecode4DSL/

%changelog
* Thu Mar 16 2023 Fabian Vogt <fvogt@suse.com>
- Update to 1.2.2:
  common:
  * Add shortcut key recognition of ctrl/shift/alt
  * Fix multiple clicks crash during file saving
  * Fix screenshot crash under macOS
  * Improve accuracy of CSV file
  for logic analyzer:
  * Support new hardware and firmware versions
  * Clean up 0: UART protocol outputs statement
  * Add CAN decoder support for CANFD
  * Fix wait error for some decoders
  * Fix QI decoder bugs
  * Fix SPDIF decoder error for incomplete frames
  * Add message type support for USB PD decoder
  for oscilloscope:
  * Fix measure error of DSL files with different channel number
- Remove various unnecessary BuildRequires
* Fri Nov 25 2022 Dmitry Roshchin <dmitry_r@opensuse.org>
- Update to version 1.2.1
- Drop deparate library packages
- Drop DSView-remove-unnecessary-extern-C.patch
- Drop qt5-includefixes.patch
* Wed Jan 12 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- added a patch DSView-remove-unnecessary-extern-C.patch, taken
  from upstream, to fix build on Tumbleweed and Leap 15.4
* Sat Feb 20 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.2:
  * fix issue of saving/loading file with special characters
  * fix issue #226, double-click open dsl file on Windows
  * improve range settings in decoders
  * add QSPI and MIPI DSI decoders
  * merge enhancement of LPC decoder
  * fix issue #300, time precision for csv export of decoder results
  * fix out-of-order issue of multiple annotation rows in one decoder
  * fix issue #306, VCD file export uses the wrong identifier codes
  * improve the icons with svg format for better high DPI display
  * fix out of screen issue when DPI scale >= 1.5 @ 1080P
  * fix type-c orientation issue for U3Pro16/U3Pro32
  * fix decoder issues (enhance detection of i2s stop and dmx512 break)
  * improve the auto gain control during auto calibration for U2B100/U3P100
  * fix issue of first trigger be ignored
  * add support for DSCope U3P100 device (100M bandwidth/1G samplerate/USB3.0 oscilloscope)
  * add support for DSLogic U3Pro32 device (32 channels/1G samplerate/USB3.0 logic analyzer)
  * add support for DSCope U2B100 device (100M bandwidth/1G samplerate/USB2.0 oscilloscope)
  * add support for DSLogic U3Pro16 device (16 channels/1G samplerate/USB3.0 logic analyzer)
  * add display of device type (USB 2.0 / USB 3.0 / Demo / File)
  * add version check for FPGA firmware
  * improve the default file name when saving/exporting files
  * fix other display and language issue
  * extend channel support for trigger up to 32 channels
  * fix issue of ps/2 decoder (#239)
  * fix issue of cec decoder (#235)
  * fix ID issue when export results of decoder (#237)
  * fix "not" logic don't work in advance trigger
  * fix other display issues
  * improve wave shake issue when trig high freqency signals
  * fix sampling point selection issue of downsampling
  * add 20M bandwidth limitation for DSCope U2B100 / DSCope U3P100 devices
  * improve synchronism between data acquisition and wave dispaly
  * fix wave display and measurement issue when change vdiv and offset after stop
  * fix capture restart issue when change offset in roll mode
  * fix issue of timebase of math channel can't be changed when waiting trigger
  * fix issue of offset can't be changed when waiting trigger
  * fix clear and flicker issue of auto measurements
  * fix cursor and mouse measurements issue after change samplerate when waiting trigger
  * fix trigger issue when toggle between different trigger source
  * fix hardware offset setting issue
  * fix mipmap issue of long time data at some case
  * add cursor and mouse measurements
- add qt5-includefixes.patch
- merge build of libsigrokdecode4DSL and libsigrok4DSL into main package
* Sun Oct  6 2019 Dmitry Roshchin <dmitry_r@opensuse.org>
- Initial package, version 1.01
